@@ -4,7 +4,7 @@ use Mojo::Base -base;
 use Encode;
 use Role::Tiny;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 has _counter_selector_prefix => '';
 
@@ -34,8 +34,9 @@ sub dive_reset {
 
 sub dived_text_is {
     my $self = shift;
-    $_[0] = $self->_counter_selector_prefix . $_[0];
-    $self->text_is( @_ );
+    my @in = @_; # can't modify in-place
+    $in[0] = $self->_counter_selector_prefix . $in[0];
+    $self->text_is( @in );
 }
 
 sub element_count_is {
